==> phpmailer-5.1.tbz: share/phpmailer/language/phpmailer.lang-cz.php <==
<?php
/**
* PHPMailer language file: refer to English translation for definitive list
* Czech Version
*/

$PHPMAILER_LANG['authenticate']         = 'SMTP Error: Chyba autentikace.';
$PHPMAILER_LANG['connect_host']         = 'SMTP Error: Nelze navázat spojení se SMTP serverem.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP Error: Data nebyla pøijata';
//$PHPMAILER_LANG['empty_message']        = 'Message body empty';
$PHPMAILER_LANG['encoding']             = 'Neznámé kódování: ';
$PHPMAILER_LANG['execute']              = 'Nelze provést: ';
$PHPMAILER_LANG['file_access']          = 'Soubor nenalezen: ';
$PHPMAILER_LANG['file_open']            = 'File Error: Nelze otevøít soubor pro ètení: ';
$PHPMAILER_LANG['from_failed']          = 'Následující adresa From je nesprávná: ';
$PHPMAILER_LANG['instantiate']          = 'Nelze vytvoøit instanci emailové funkce.';
//$PHPMAILER_LANG['invalid_email']        = 'Not sending, email address is invalid: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailový klient není podporován.';
$PHPMAILER_LANG['provide_address']      = 'Musíte zadat alespoò jednu emailovou adresu pøíjemce.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP Error: Adresy pøíjemcù nejsou správné ';
//$PHPMAILER_LANG['signing']              = 'Signing Error: ';
//$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() failed.';
//$PHPMAILER_LANG['smtp_error']           = 'SMTP server error: ';
//$PHPMAILER_LANG['variable_set']         = 'Cannot set or reset variable: ';
?>

==> phpmailer-5.2.6.tbz: share/phpmailer/language/phpmailer.lang-cz.php <==
<?php
/**
* PHPMailer language file: refer to English translation for definitive list
* Czech Version
*/

$PHPMAILER_LANG['authenticate']         = 'SMTP Error: Chyba autentikace.';
$PHPMAILER_LANG['connect_host']         = 'SMTP Error: Nelze navázat spojení se SMTP serverem.';
$PHPMAILER_LANG['data_not_accepted']    = 'SMTP Error: Data nebyla pøijata';
//$PHPMAILER_LANG['empty_message']        = 'Message body empty';
$PHPMAILER_LANG['encoding']             = 'Neznámé kódování: ';
$PHPMAILER_LANG['execute']              = 'Nelze provést: ';
$PHPMAILER_LANG['file_access']          = 'Soubor nenalezen: ';
$PHPMAILER_LANG['file_open']            = 'File Error: Nelze otevøít soubor pro ètení: ';
$PHPMAILER_LANG['from_failed']          = 'Následující adresa From je nesprávná: ';
$PHPMAILER_LANG['instantiate']          = 'Nelze vytvoøit instanci emailové funkce.';
//$PHPMAILER_LANG['invalid_address']        = 'Not sending, email address is invalid: ';
$PHPMAILER_LANG['mailer_not_supported'] = ' mailový klient není podporován.';
$PHPMAILER_LANG['provide_address']      = 'Musíte zadat alespoò jednu emailovou adresu pøíjemce.';
$PHPMAILER_LANG['recipients_failed']    = 'SMTP Error: Adresy pøíjemcù nejsou správné ';
//$PHPMAILER_LANG['signing']              = 'Signing Error: ';
//$PHPMAILER_LANG['smtp_connect_failed']  = 'SMTP Connect() failed.';
//$PHPMAILER_LANG['smtp_error']           = 'SMTP server error: ';
//$PHPMAILER_LANG['variable_set']         = 'Cannot set or reset variable: ';
